RedisCluster.Cluster.RoleParser (redis_cluster v0.8.0)
View SourceParses the output of the ROLE command. This is used when using a standalone Redis instance instead of a cluster.
Summary
Functions
Parses the output of the ROLE command.
Parses the output of the ROLE command. This is used when using a standalone Redis instance instead of a cluster.
Parses the output of the ROLE command.