RedisCluster.Cluster.SlotParser (redis_cluster v0.8.0)
View SourceParses the output of the CLUSTER SLOTS command. This is included to support Redis clusters older than v7.0.0.
Summary
Functions
Parses the output of the CLUSTER SLOTS command.
Parses the output of the CLUSTER SLOTS command. This is included to support Redis clusters older than v7.0.0.
Parses the output of the CLUSTER SLOTS command.