RedisCluster.RedisAdapter behaviour (redis_cluster v0.8.0)
View SourceA behaviour module for Redis adapters. This is intended for mocking Redis in the tests. Though it could also be used to work with Redis libraries other than Redix.
A behaviour module for Redis adapters. This is intended for mocking Redis in the tests. Though it could also be used to work with Redis libraries other than Redix.